@@ -54,7 +54,7 @@
 
 #ifdef OFFLINE
 #ifdef HAVE_RAPTOR
-#include <raptor.h>
+#include <raptor2.h>
 #endif
 #endif
 
@@ -76,13 +76,16 @@ const char* const flickcurl_version_string = VERSION;
 const char* const flickcurl_flickr_service_uri =  "http://www.flickr.com/services/rest/?";
 const char* const flickcurl_flickr_upload_service_uri =  "http://api.flickr.com/services/upload/";
 const char* const flickcurl_flickr_replace_service_uri =  "http://api.flickr.com/services/replace/";
+const char* const flickcurl_flickr_oauth_request_token_uri =  "http://www.flickr.com/services/oauth/request_token";
+const char* const flickcurl_flickr_oauth_authorize_uri =  "http://www.flickr.com/services/oauth/authorize";
+const char* const flickcurl_flickr_oauth_access_token_uri =  "http://www.flickr.com/services/oauth/access_token";
 
 
 static void
 flickcurl_error_varargs(flickcurl* fc, const char *message, 
                         va_list arguments)
 {
-  if(fc->error_handler) {
+  if(fc && fc->error_handler) {
     char *buffer = my_vsnprintf(message, arguments);
     if(!buffer) {
       fprintf(stderr, "flickcurl: Out of memory\n");
@@ -209,10 +212,21 @@ flickcurl_new_with_handle(void* curl_handle)
   fc->service_uri = strdup(flickcurl_flickr_service_uri);
   fc->upload_service_uri = strdup(flickcurl_flickr_upload_service_uri);
   fc->replace_service_uri = strdup(flickcurl_flickr_replace_service_uri);
+  fc->oauth_request_token_uri = strdup(flickcurl_flickr_oauth_request_token_uri);
+  fc->oauth_access_token_uri = strdup(flickcurl_flickr_oauth_access_token_uri);
 
   /* DEFAULT delay between requests is 1000ms i.e 1 request/second max */
   fc->request_delay = 1000;
-  
+
+#ifdef FLICKCURL_OAUTH
+  fc->mt = mtwist_new();
+  if(!fc->mt) {
+    free(fc);
+    return NULL;
+  }
+  mtwist_init(fc->mt, mtwist_seed_from_system(fc->mt));
+#endif
+
   fc->curl_handle = (CURL*)curl_handle;
   if(!fc->curl_handle) {
     fc->curl_handle = curl_easy_init();
@@ -335,6 +349,10 @@ flickcurl_free(flickcurl *fc)
     free(fc->upload_service_uri);
   if(fc->replace_service_uri)
     free(fc->replace_service_uri);
+  if(fc->oauth_request_token_uri)
+    free(fc->oauth_request_token_uri);
+  if(fc->oauth_access_token_uri)
+    free(fc->oauth_access_token_uri);
 
   if(fc->user_agent)
     free(fc->user_agent);
@@ -342,6 +360,13 @@ flickcurl_free(flickcurl *fc)
   if(fc->uri)
     free(fc->uri);
 
+#ifdef FLICKCURL_OAUTH
+  if(fc->mt)
+    mtwist_free(fc->mt);
+
+  flickcurl_oauth_free(&fc->od);
+#endif
+
   free(fc);
 }
 
@@ -1387,7 +1412,8 @@ flickcurl_invoke_common(flickcurl *fc, char** content_p, size_t* size_p,
   if(curl_easy_perform(fc->curl_handle)) {
     /* failed */
     fc->failed = 1;
-    flickcurl_error(fc, fc->error_buffer);
+    flickcurl_error(fc, "Method %s failed with CURL error %s",
+                    fc->method, fc->error_buffer);
   } else {
     long lstatus;
 
@@ -1395,21 +1421,22 @@ flickcurl_invoke_common(flickcurl *fc, char** content_p, size_t* size_p,
 #define CURLINFO_RESPONSE_CODE CURLINFO_HTTP_CODE
 #endif
 
+    fc->status_code = 0;
     /* Requires pointer to a long */
     if(CURLE_OK == 
-       curl_easy_getinfo(fc->curl_handle, CURLINFO_RESPONSE_CODE, &lstatus) ) {
+       curl_easy_getinfo(fc->curl_handle, CURLINFO_RESPONSE_CODE, &lstatus) )
       fc->status_code = lstatus;
-      if(fc->status_code != 200) {
-        if(fc->method)
-          flickcurl_error(fc, "Method %s failed with error %d - %s (HTTP %d)", 
-                          fc->method, fc->error_code, fc->error_msg,
-                          fc->status_code);
-        else
-          flickcurl_error(fc, "Call failed with error %d - %s (HTTP %d)", 
-                          fc->error_code, fc->error_msg,
-                          fc->status_code);
-        fc->failed = 1;
-      }
+
+    if(fc->status_code != 200) {
+      if(fc->method)
+        flickcurl_error(fc, "Method %s failed with error %d - %s (HTTP %d)", 
+                        fc->method, fc->error_code, fc->error_msg,
+                        fc->status_code);
+      else
+        flickcurl_error(fc, "Call failed with error %d - %s (HTTP %d)", 
+                        fc->error_code, fc->error_msg,
+                        fc->status_code);
+      fc->failed = 1;
     }
 
   }
@@ -1570,6 +1597,78 @@ flickcurl_invoke_get_content(flickcurl *fc, size_t* size_p)
 }
 
 
+void
+flickcurl_free_form(char **form, int count)
+{
+  if(!form)
+    return;
+
+  /* free content which is the first key */
+  free(form[0]);
+
+  free(form);
+}
+
+
+char**
+flickcurl_invoke_get_form_content(flickcurl *fc, int* count_p)
+{
+  char* content = NULL;
+  char** form = NULL;
+  char *p;
+  int count;
+  int i;
+
+  if(flickcurl_invoke_common(fc, &content, NULL, NULL))
+    return NULL;
+
+  for(p = content, count = 0; *p; p++) {
+    if(*p == '&')
+      count++;
+  }
+  count++; /* counting separators so need +1 for number of contents */
+  
+  /* Allocate count + 1 sized array of char* (key, value) pointers
+   * The last pair are always (NULL, NULL).
+   *
+   * The pointers are into the 'content' buffer which is kept around
+   * and owned by this array and stored in form[0].
+   */
+  form = (char**)calloc(2*(count + 1), sizeof(char*));
+  if(!form)
+    goto tidy;
+
+  for(p = content, i = 0; *p; p++) {
+    char *start = p;
+    
+    while(*p && *p != '&' && *p != '=')
+      p++;
+
+    form[i++] = start;
+
+    if(!*p)
+      break;
+    *p = '\0';
+  }
+  form[i++] = '\0';
+  form[i] = '\0';
+  
+  if(count_p)
+    *count_p = count;
+
+  return form;
+
+  tidy:
+  if(form)
+    free(form);
+
+  if(content)
+    free(content);
+  
+  return NULL;
+}
+
+
 char*
 flickcurl_unixtime_to_isotime(time_t unix_time)
 {
@@ -2090,6 +2189,64 @@ flickcurl_get_safety_level_from_string(const char* safety_level_string)
 }
 
 
+#define HIDDEN_COUNT 2
+static const char* flickcurl_hidden_labels[HIDDEN_COUNT + 1] =
+  {"unknown", "public", "hidden" };
+
+
+/**
+ * flickcurl_get_hidden_label:
+ * @hidden: safety level index
+ * 
+ * Get label for a hidden status
+ *
+ * Return value: pointer to shared string label for hidden status or "unknown"
+ **/
+const char*
+flickcurl_get_hidden_label(int hidden)
+{
+  if(hidden < 1 || hidden > HIDDEN_COUNT)
+    hidden = 0;
+
+  return flickcurl_hidden_labels[hidden];
+}
+
+
+/**
+ * flickcurl_get_hidden_from_string:
+ * @hidden_string: string
+ * 
+ * Get the enumeration value for a hidden status string.
+ *
+ * Parses the string value into a safety level either from an
+ * integer form like '1' or a label like 'hidden'.
+ * 
+ * Returns: safety level enumeration value or <0 on error
+ **/
+int
+flickcurl_get_hidden_from_string(const char* hidden_string)
+{
+  char* endptr = NULL;
+  int hidden = -1;
+
+  hidden = (int)strtol(hidden_string, &endptr, 10);
+  /* If not all of string was used - fail */
+  if(endptr && *endptr)
+    hidden = -1;
+
+  if(hidden < 1 || hidden > HIDDEN_COUNT) {
+    int i;
+    for(i = 1; i< HIDDEN_COUNT; i++)
+      if(!strcmp(flickcurl_hidden_labels[i], hidden_string)) {
+        hidden = i;
+        break;
+      }
+  }
+
+  return hidden;
+}
+
+
 #define FEED_FORMAT_COUNT 8
 static struct {
   const char* name;
