@@ -1040,6 +1040,7 @@ typedef struct {
  * @title: title of photoset
  * @description: description of photoset (may be NULL)
  * @photos: photos in a photoset (may be NULL)
+ * @owner: owner NSID
  *
  * A photoset.
  *
@@ -1054,6 +1055,7 @@ typedef struct {
   char* title;
   char *description;
   struct flickcurl_photo_s** photos;
+  char *owner; 
 } flickcurl_photoset;
 
 
@@ -1236,6 +1238,7 @@ typedef struct {
  * @is_family: is family photo boolean (non-0 true)
  * @safety_level: 1=safe, 2=moderate, 3=restricted
  * @content_type: 1=photo, 2=screenshot, 3=other/artwork
+ * @hidden: 1=in global search, 2=hidden from publish searches (Flickcurl 1.22+)
  *
  * Photo upload parameters
  */
@@ -1249,6 +1252,8 @@ typedef struct {
   int is_family;  
   int safety_level;
   int content_type;
+  /* Flickcurl 1.22+ */
+  int hidden;
 } flickcurl_upload_params;
 
 
@@ -1599,6 +1604,12 @@ FLICKCURL_API
 extern const char* const flickcurl_flickr_upload_service_uri;
 FLICKCURL_API
 extern const char* const flickcurl_flickr_replace_service_uri;
+FLICKCURL_API
+extern const char* const flickcurl_flickr_oauth_request_token_uri;
+FLICKCURL_API
+extern const char* const flickcurl_flickr_oauth_authorize_uri;
+FLICKCURL_API
+extern const char* const flickcurl_flickr_oauth_access_token_uri;
 
 
 /* library init - call once before creating anything */
@@ -1679,6 +1690,8 @@ void flickcurl_free_tag_namespaces(flickcurl_tag_namespace** tag_nspaces);
 FLICKCURL_API
 void flickcurl_free_tag(flickcurl_tag *t);
 FLICKCURL_API
+void flickcurl_free_tags(flickcurl_tag **tags);
+FLICKCURL_API
 void flickcurl_free_tag_clusters(flickcurl_tag_clusters *tcs);
 FLICKCURL_API
 void flickcurl_free_photo(flickcurl_photo *photo);
@@ -1775,6 +1788,10 @@ const char* flickcurl_get_safety_level_label(int safety_level);
 FLICKCURL_API
 int flickcurl_get_safety_level_from_string(const char* safety_level_string);
 FLICKCURL_API
+const char* flickcurl_get_hidden_label(int hidden);
+FLICKCURL_API
+int flickcurl_get_hidden_from_string(const char* hidden_string);
+FLICKCURL_API
 int flickcurl_get_feed_format_info(int feed_format, const char** name_p, const char** label_p, const char** mime_type_p);
 FLICKCURL_API
 int flickcurl_get_extras_format_info(int extras_format, const char** name_p, const char** label_p);
@@ -1793,10 +1810,14 @@ int flickcurl_search_params_init(flickcurl_search_params* params);
  * Handler to get variables returned from an 'INI' style configuration file
 */
 typedef void (*set_config_var_handler)(void* userdata, const char* key, const char* value);
+FLICKCURL_API FLICKCURL_DEPRECATED
+int read_ini_config(const char* filename, const char* section, void* user_data, set_config_var_handler handler);
 FLICKCURL_API
-int read_ini_config(const char* filename, const char* application, void* user_data, set_config_var_handler handler);
-
-
+int flickcurl_config_read_ini(flickcurl* fc, const char* filename, const char* section, void* user_data, set_config_var_handler handler);
+FLICKCURL_API
+void flickcurl_config_var_handler(void* userdata, const char* key, const char* value);
+FLICKCURL_API
+int flickcurl_config_write_ini(flickcurl *fc, const char* filename, const char* section);
 
 /* Flickr API calls */
 
@@ -1817,7 +1838,9 @@ FLICKCURL_API
 char* flickcurl_auth_getFullToken(flickcurl* fc, const char* frob);
 FLICKCURL_API
 char* flickcurl_auth_getToken(flickcurl* fc, const char* frob);
-
+FLICKCURL_API
+int flickcurl_auth_oauth_getAccessToken(flickcurl* fc);
+  
 /* flickr.blogs */
 FLICKCURL_API
 flickcurl_blog** flickcurl_blogs_getList(flickcurl* fc);
@@ -1846,6 +1869,8 @@ const char* flickcurl_get_institution_url_type_label(flickcurl_institution_url_t
 FLICKCURL_API
 int flickcurl_favorites_add(flickcurl* fc, const char* photo_id);
 FLICKCURL_API
+flickcurl_photos_list** flickcurl_favorites_getContext(flickcurl* fc, const char* photo_id, const char* user_id, int num_prev, int num_next, const char* extras);
+FLICKCURL_API
 flickcurl_photo** flickcurl_favorites_getList(flickcurl* fc, const char* user_id, const char* extras, int per_page, int page);
 FLICKCURL_API
 flickcurl_photos_list* flickcurl_favorites_getList_params(flickcurl* fc, const char* user_id, flickcurl_photos_list_params* list_params);
