@@ -24,9 +24,13 @@
 #include <libxml/xpath.h>
 
 #include <curl/curl.h>
-#include <curl/types.h>
 #include <curl/easy.h>
 
+#include <mtwist_config.h>
+
+#ifdef FLICKCURL_OAUTH
+#include <mtwist.h>
+#endif
 
 #if defined (OFFLINE) && defined (CAPTURE)
 #error "Cannot define both OFFLINE and CAPTURE"
@@ -116,6 +120,9 @@ int flickcurl_prepare_upload(flickcurl *fc, const char* url, const char* upload_
 xmlDocPtr flickcurl_invoke(flickcurl *fc);
 /* Invoke Flickr API at URi prepared above and get back raw content */
 char* flickcurl_invoke_get_content(flickcurl *fc, size_t* size_p);
+/* Invoke URI prepared above and get back 'count' key/values */
+char** flickcurl_invoke_get_form_content(flickcurl *fc, int* count_p);
+void flickcurl_free_form(char **form, int count);
 
 /* args.c */
 void flickcurl_free_arg(flickcurl_arg *arg);
@@ -211,6 +218,7 @@ flickcurl_person** flickcurl_build_persons(flickcurl* fc, xmlXPathContextPtr xpa
 flickcurl_person* flickcurl_build_person(flickcurl* fc, xmlXPathContextPtr xpathCtx, const xmlChar* root_xpathExpr);
 
 /* photo.c */
+flickcurl_photos_list* flickcurl_new_photos_list(flickcurl* fc);
 flickcurl_photo** flickcurl_build_photos(flickcurl* fc, xmlXPathContextPtr xpathCtx, const xmlChar* xpathExpr, int* photo_count_p);
 flickcurl_photo* flickcurl_build_photo(flickcurl* fc, xmlXPathContextPtr xpathCtx);
 flickcurl_photos_list* flickcurl_invoke_photos_list(flickcurl* fc, const xmlChar* xpathExpr, const char* format);
@@ -257,6 +265,50 @@ struct flickcurl_chunk_s {
 typedef struct flickcurl_chunk_s flickcurl_chunk;
 
 
+#ifdef FLICKCURL_OAUTH
+typedef struct {
+  /* client credentials */
+  char* client_key; /* AKA consumer key or the Flickr API key */
+  size_t client_key_len;
+  char* client_secret;
+  size_t client_secret_len;
+
+  /* temporary credentials */
+  char* request_token;
+  size_t request_token_len;
+  char* request_token_secret;
+  size_t request_token_secret_len;
+  
+  const char* verifier; /* OAuth verifier - always shared */
+  size_t verifier_len;
+
+  /* token credentials */
+  char* token; /* AKA access token */
+  size_t token_len;
+  char* token_secret;
+  size_t token_secret_len;
+  
+  /* callback URI or NULL for "oob" */
+  const char* callback; /* always shared */
+  size_t callback_len;
+
+  /* Generally leave as NULL to make it new each time */
+  char* nonce;
+
+  /* Generally leave as 0 to make it use current time with gettimeofday() */
+  time_t timestamp;
+
+  /* HMAC-SHA1 key */
+  unsigned char *key;
+  size_t key_len;
+
+  /* HMAC-SHA1 data */
+  unsigned char* data;
+  size_t data_len;
+} flickcurl_oauth_data;
+#endif  
+
+
 struct flickcurl_s {
   int total_bytes;
 
@@ -368,6 +420,22 @@ struct flickcurl_s {
 
   flickcurl_curl_setopt_handler curl_setopt_handler;
   void* curl_setopt_handler_data;
+
+  /* OAuth request token Web Service URI */
+  char *oauth_request_token_uri;
+
+  /* OAuth authorize URI */
+  char *oauth_authorize_uri;
+
+  /* OAuth access token Web Service URI */
+  char *oauth_access_token_uri;
+
+#if FLICKCURL_OAUTH
+  /*  Used for OAuth nonce generation */
+  mtwist* mt;
+
+  flickcurl_oauth_data od;
+#endif
 };
 
 struct flickcurl_serializer_s
@@ -379,3 +447,24 @@ struct flickcurl_serializer_s
 
 void flickcurl_serializer_init(void);
 void flickcurl_serializer_terminate(void);
+
+
+#ifdef FLICKCURL_OAUTH
+
+/* sha1.c */
+#define SHA1_DIGEST_LENGTH 20
+unsigned char* flickcurl_hmac_sha1(const void *data, size_t data_len, const void *key, size_t key_len);
+
+
+/* oauth.c */
+
+#define FLICKCURL_MAX_OAUTH_PARAM_COUNT 8
+
+
+void flickcurl_oauth_free(flickcurl_oauth_data* od);
+char* flickcurl_oauth_compute_signature(flickcurl_oauth_data* od, size_t* len_p);
+int flickcurl_oauth_prepare_common(flickcurl *fc, const char* url, const char* method, const char* upload_field, const char* upload_value, const char* parameters[][2], int count, int parameters_in_url, int need_auth);
+int flickcurl_oauth_request_token(flickcurl* fc);
+char* flickcurl_oauth_get_authorize_uri(flickcurl* fc);
+int flickcurl_oauth_access_token(flickcurl* fc, const char* verifier);
+#endif
