@@ -134,9 +134,7 @@ flickcurl_free_photo(flickcurl_photo *photo)
       free(photo->fields[i].string);
   }
   
-  for(i = 0; i < photo->tags_count; i++)
-    flickcurl_free_tag(photo->tags[i]);
-  free(photo->tags);
+  flickcurl_free_tags(photo->tags);
 
   for(i = 0; i < photo->notes_count; i++)
     flickcurl_free_note(photo->notes[i]);
@@ -1216,16 +1214,7 @@ flickcurl_invoke_photos_list(flickcurl* fc, const xmlChar* xpathExpr,
   const char *nformat;
   size_t format_len;
 
-  photos_list = (flickcurl_photos_list*)calloc(1, sizeof(*photos_list));
-  if(!photos_list) {
-    fc->failed = 1;
-    goto tidy;
-  }
-
-  photos_list->page = -1;
-  photos_list->per_page = -1;
-  photos_list->total_count = -1;
-  
+  photos_list = flickcurl_new_photos_list(fc);
   if(format) {
     nformat = format;
     format_len = strlen(format);
@@ -1358,6 +1347,29 @@ flickcurl_invoke_photos_list(flickcurl* fc, const xmlChar* xpathExpr,
 }
 
 
+/*
+ * flickcurl_new_photos_list:
+ * @fc: Flickcurl context
+ *
+ * INTERNAL - constructor for photos list
+ */
+flickcurl_photos_list*
+flickcurl_new_photos_list(flickcurl* fc)
+{
+  flickcurl_photos_list* photos_list;
+  
+  photos_list = (flickcurl_photos_list*)calloc(1, sizeof(*photos_list));
+  if(!photos_list)
+    return NULL;
+
+  photos_list->page = -1;
+  photos_list->per_page = -1;
+  photos_list->total_count = -1;
+
+  return photos_list;
+}
+  
+
 /**
  * flickcurl_free_photos_list:
  * @photos_list: photos list object
